@@ -1,18 +1,17 @@
 "use strict";
+
 /*
  * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
  * or more contributor license agreements. Licensed under the Elastic License
  * 2.0; you may not use this file except in compliance with the Elastic License
  * 2.0.
  */
+
 // eslint-disable-next-line import/no-extraneous-dependencies
-
-require('@kbn/optimizer').registerNodeAutoTranspilation();
-
+require('@kbn/babel-register').registerNodeAutoTranspilation();
 const {
   aggregateLatencyMetrics
 } = require('./aggregate-latency-metrics/index.ts');
-
 aggregateLatencyMetrics().catch(err => {
   if (err.meta && err.meta.body) {
     // error from elasticsearch client
@@ -20,6 +19,5 @@ aggregateLatencyMetrics().catch(err => {
   } else {
     console.error(err);
   }
-
   process.exit(1);
 });
\ No newline at end of file
