@@ -1,4 +1,5 @@
 "use strict";
+
 /*
  * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
  * or more contributor license agreements. Licensed under the Elastic License
@@ -16,9 +17,8 @@
  * This makes it possible to use the existing cloud users locally
  * Usage: node create-apm-users-and-roles.js --role-suffix <YOUR-GITHUB-USERNAME-OR-SOMETHING-UNIQUE>
  ******************************/
+
 // compile typescript on the fly
 // eslint-disable-next-line import/no-extraneous-dependencies
-
-require('@kbn/optimizer').registerNodeAutoTranspilation();
-
+require('@kbn/babel-register').registerNodeAutoTranspilation();
 require('./create-apm-users-and-roles/create_apm_users_and_roles_cli.ts');
\ No newline at end of file
